@@ -48,8 +48,8 @@ class GuestQemuProc(Collector):
         self.pid_stat_file.seek(0)
         try:
             stats = self.pid_stat_file.read().split()
-        except IOError, (errno, strerror):
-            raise CollectionError("Cannot read stat file: %s" % strerror)
+        except IOError as e:
+            raise CollectionError("Cannot read stat file: %s" % e.strerror)
         cur_minor_faults = int(stats[9])
         cur_major_faults = int(stats[11])
         rss = int(stats[23])
