@@ -22,13 +22,15 @@ import tempfile
 import os
 import os.path
 import shutil
-import ConfigParser
 import mom
+import mock
+from six.moves import configparser
+from six.moves import xmlrpc_client
 
 
 def start_mom(config=None):
     if not config:
-        config = ConfigParser.SafeConfigParser()
+        config = configparser.SafeConfigParser()
         config.add_section('logging')
         config.set('logging', 'verbosity', 'error')
 
@@ -75,7 +77,7 @@ class GeneralTests(TestCaseBase):
         self.assertEquals('0', self.mom_instance.getPolicy())
 
     def testMultiplePolicies(self):
-        self.assertEquals(0, len(self.mom_instance.getNamedPolicies().keys()))
+        self.assertEquals(0, len(list(self.mom_instance.getNamedPolicies().keys())))
 
         self.mom_instance.setNamedPolicy("10_test", "(+ 1 1)")
         self.mom_instance.setNamedPolicy("20_test", "(- 1 1)")
@@ -94,12 +96,12 @@ class ConfigTests(TestCaseBase):
             '02_bar': '(- 2 1)'
         }
         policy_dir = tempfile.mkdtemp()
-        for name, policy in policies.items():
+        for name, policy in list(policies.items()):
             with open(os.path.join(policy_dir, name + '.policy'), 'w') as f:
                 f.write(policy)
 
 
-        config = ConfigParser.SafeConfigParser()
+        config = configparser.SafeConfigParser()
         config.add_section('main')
         config.set('main', 'policy-dir', policy_dir)
         config.add_section('logging')
@@ -117,6 +119,47 @@ class ConfigTests(TestCaseBase):
             mom_instance.resetPolicies()
             self.assertEquals('(+ 1 1)', policies['01_foo'])
             self.assertEquals('(- 2 1)', policies['02_bar'])
-            self.assertTrue('03_baz' not in policies.iterkeys())
+            self.assertTrue('03_baz' not in iter(policies.keys()))
         finally:
             shutil.rmtree(policy_dir)
+
+
+class RpcTests(TestCaseBase):
+    def testBigNumbersInStats(self):
+        host_monitor = mock.Mock()
+        host_monitor.interrogate.return_value.statistics = [{
+            "ksm_run": 1,
+            "ksm_pages": 100,
+            "huge_number": 2**31 + 2**10
+        }]
+
+        vm1 = mock.Mock()
+        vm1.properties = {"name": "vm1"}
+        vm1.statistics = [{
+            "free_mem": 25 * 2**30 # 25 TiB (in KiB)
+        }]
+
+        vm2 = mock.Mock()
+        vm2.properties = {"name": "vm2"}
+        vm2.statistics = [{
+            "free_mem": 30 * 2**20 # 30 GiB (in KiB)
+        }]
+
+        guest_manager = mock.Mock()
+        guest_manager.interrogate.return_value.values.return_value = [
+            vm1, vm2
+        ]
+
+        threads = {
+            "host_monitor": host_monitor,
+            "guest_manager": guest_manager
+        }
+
+        funcs = mom.MOMFuncs(None, threads)
+        data = funcs.getStatistics()
+
+        mom.enable_i8()
+        packet = xmlrpc_client.dumps((data,))
+        (reply,), func = xmlrpc_client.loads(packet)
+
+        self.assertEqual(data, reply)
